SSH and GPG public keys for Tétras Libre collaborators

[[_TOC_]]

# SSH
SSH is used for Git access, among other things.
## Creating SSH key
```sh
ssh-keygen -t ed25519 -f ~/.ssh/<your-name>_ed25519
```
If necessary, you can use the traditional RSA key type, instead of Ed25519, just use `-t rsa` instead and `<your-name>_rsa` for the key name.

From the [Arch Linux wiki page](https://wiki.archlinux.org/title/SSH_keys#Generating_an_SSH_key_pair):
> You can also add an optional comment to the public key with the `-C` switch, to more easily identify it in places such as `~/.ssh/known_hosts` [...]. For example:
```sh
-C "$(whoami)@$(uname -n)-$(date -I)"
```
> will add a comment saying which user created the key on which machine and when (like `user@machine-2023-08-14`)

## Adding key to the repo
Simply copy your key from `~/.ssh/` to the repo's `SSH` folder.  
**Be careful to add the `.pub` key and not your private key!**


# GPG
GPG is used for [pass](https://gitlab.tetras-libre.fr/tetras-libre-admin/pass)

## Creating GPG key
```sh
gpg --generate-key
```
and follow dialog.

## Add key of Tétras Libre collaborators
To import a gpg key, use `gpg --import <key file>`. To import all keys, go to GPG folder and use `gpg --import *`

After that, you need to edit confidence of the key. For this, use `gpg --edit-key <keyName>` and use `trust` command in gpg (`gpg>trust`)
Answer the response to add the confidence `5 - ultimate`. Use `quit` to leave.

## Export the key
Find the ID of your key, for example with
```sh
gpg --list-keys | grep -i -B 2 <your name>
```
Then export it
```sh
gpg --export --armor --output '<your.email@tetras-libre.fr_pub.asc' <key id>
```
Finally copy the `.asc` key file to the GPG folder (if it's not already there)
